;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "solarized-theme" "2.1.0"
  "The Solarized color theme."
  '((emacs "24.1"))
  :url "https://github.com/bbatsov/solarized-emacs"
  :commit "0972a0f1471ed67211b7c8918a3c049380050d7b"
  :revdesc "0972a0f1471e"
  :keywords '("convenience" "themes" "solarized")
  :authors '(("Bozhidar Batsov" . "bozhidar@batsov.dev"))
  :maintainers '(("Bozhidar Batsov" . "bozhidar@batsov.dev")))
